from enum import Enum


class AttestationEngineType(str, Enum):
    """
    Enumeration of supported attestation engine types.

    This enum defines the set of attestation backends that can be selected
    when instantiating an AttestationEngine via the factory.
    """


    AMD_SEV_SNP = "amd_sev_snp"
    INTEL_TDX = "intel_tdx"